@@ -1,6 +1,6 @@
 package Test::BDD::Cucumber::Parser;
 BEGIN {
-  $Test::BDD::Cucumber::Parser::VERSION = '0.06';
+  $Test::BDD::Cucumber::Parser::VERSION = '0.07';
 }
 
 =head1 NAME
@@ -9,7 +9,7 @@ Test::BDD::Cucumber::Parser - Parse Feature files
 
 =head1 VERSION
 
-version 0.06
+version 0.07
 
 =head1 DESCRIPTION
 
@@ -85,6 +85,7 @@ sub _remove_next_blanks {
 
 sub _extract_feature_name {
 	my ( $self, $feature, @lines ) = @_;
+	my @feature_tags = ();
 
 	while ( my $line = shift( @lines ) ) {
 		next if $line->is_comment;
@@ -93,7 +94,15 @@ sub _extract_feature_name {
 		if ( $line->content =~ m/^Feature: (.+)/ ) {
 			$feature->name( $1 );
 			$feature->name_line( $line );
+			$feature->tags( \@feature_tags );
+
 			last;
+
+		# Feature-level tags
+		} elsif ( $line->content =~ m/^\s*\@\w/ ) {
+			my @tags = $line->content =~ m/\@([^\s]+)/g;
+			push( @feature_tags, @tags );
+
 		} else {
 			ouch 'parse_error', "Malformed feature line", $line;
 		}
@@ -122,6 +131,7 @@ sub _extract_conditions_of_satisfaction {
 sub _extract_scenarios {
 	my ( $self, $feature, @lines ) = @_;
 	my $scenarios = 0;
+	my @scenario_tags;
 
 	while ( my $line = shift( @lines ) ) {
 		next if $line->is_comment || $line->is_blank;
@@ -139,8 +149,10 @@ sub _extract_scenarios {
 			my $scenario = Test::BDD::Cucumber::Model::Scenario->new({
 				( $name ? ( name => $name ) : () ),
 				background => $type eq 'Background' ? 1 : 0,
-				line       => $line
+				line       => $line,
+				tags       => [@{$feature->tags}, @scenario_tags]
 			});
+			@scenario_tags = ();
 
 			# Attempt to populate it
 			@lines = $self->_extract_steps( $feature, $scenario, @lines );
@@ -150,6 +162,12 @@ sub _extract_scenarios {
 			} else {
 				push( @{ $feature->scenarios }, $scenario );
 			}
+
+		# Scenario-level tags
+		} elsif ( $line->content =~ m/^\s*\@\w/ ) {
+			my @tags = $line->content =~ m/\@([^\s]+)/g;
+			push( @scenario_tags, @tags );
+
 		} else {
 			ouch 'parse_error', "Malformed scenario line", $line;
 		}
